==> senior_design_system-2.1.3.tar.gz: example/lib/pages/info_card.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class InfoCardExample extends StatelessWidget {
  final int _yesterday = 248;
  final int _deliveries = 25;
  final int _orders = 32;

  const InfoCardExample({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Info Card',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              Panel(
                title: 'Normal',
                child: Center(
                  child: SeniorInfoCard(
                    label: 'Ontem',
                    value: '$_yesterday',
                    severityColor: SeniorColors.manchesterColorBlue,
                  ),
                ),
              ),
              Panel(
                title: 'Cards em linha',
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    SeniorInfoCard(
                      label: 'Pedidos',
                      value: '$_orders',
                      severityColor: SeniorColors.manchesterColorOrange,
                    ),
                    SeniorInfoCard(
                      label: 'Entregas',
                      value: '$_deliveries',
                      severityColor: SeniorColors.manchesterColorGreen,
                    ),
                  ],
                ),
              ),
              Panel(
                title: 'Card com máxima largura',
                child: SeniorInfoCard(
                  label: 'Pendentes',
                  value: '${_orders - _deliveries}',
                  severityColor: SeniorColors.manchesterColorBlue,
                  fullLength: true,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> senior_design_system-6.0.0.tar.gz: example/lib/pages/info_card.example.dart <==
import 'package:flutter/material.dart';

import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../widgets/panel.dart';
import '../widgets/page_wrapper.dart';

class InfoCardExample extends StatelessWidget {
  const InfoCardExample({
    Key? key,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return const PageWrapper(
      title: 'Info Card',
      child: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.stretch,
            children: [
              Panel(
                title: 'Normal',
                child: Center(
                  child: SeniorInfoCard(
                    label: 'Ontem',
                    value: '248',
                    severityColor: SeniorColors.manchesterColorBlue,
                  ),
                ),
              ),
              Panel(
                title: 'Cards em linha',
                child: Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: [
                    SeniorInfoCard(
                      label: 'Pedidos',
                      value: '32',
                      severityColor: SeniorColors.manchesterColorOrange,
                    ),
                    SeniorInfoCard(
                      label: 'Entregas',
                      value: '25',
                      severityColor: SeniorColors.manchesterColorGreen,
                    ),
                  ],
                ),
              ),
              Panel(
                title: 'Card com máxima largura',
                child: SeniorInfoCard(
                  label: 'Pendentes',
                  value: '7',
                  severityColor: SeniorColors.manchesterColorBlue,
                  fullLength: true,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
